#[repr(transparent)]pub struct Script(TinyAsciiStr<4>);Expand description
A script subtag (examples: "Latn", "Arab", etc.)
Script represents a Unicode script code conformant to the
unicode_script_subtag field of the Language and Locale Identifier,
i.e. an ISO 15924 value.
Examples
use icu::locale::subtags::Script;
let script: Script =
"Latn".parse().expect("Failed to parse a script subtag.");Tuple Fields
0: TinyAsciiStr<4>Implementations
Sourceimpl Script
impl Script
Sourcepub const fn try_from_str(s: &str) -> Result<Script, ParseError>
pub const fn try_from_str(s: &str) -> Result<Script, ParseError>
Sourcepub const fn try_from_utf8(code_units: &[u8]) -> Result<Script, ParseError>
pub const fn try_from_utf8(code_units: &[u8]) -> Result<Script, ParseError>
Sourcepub const fn try_from_raw(raw: [u8; 4]) -> Result<Script, ParseError>
pub const fn try_from_raw(raw: [u8; 4]) -> Result<Script, ParseError>
Safely creates a Script from its raw format
as returned by Self::into_raw. Unlike Self::try_from_utf8,
this constructor only takes normalized values.
Sourcepub const unsafe fn from_raw_unchecked(v: [u8; 4]) -> Script
pub const unsafe fn from_raw_unchecked(v: [u8; 4]) -> Script
Unsafely creates a Script from its raw format
as returned by Self::into_raw. Unlike Self::try_from_utf8,
this constructor only takes normalized values.
Safety
This function is safe iff Self::try_from_raw returns an Ok. This is the case
for inputs that are correctly normalized.
Sourcepub const fn into_raw(self) -> [u8; 4]
pub const fn into_raw(self) -> [u8; 4]
Deconstructs into a raw format to be consumed by
from_raw_unchecked or
try_from_raw.
Sourcepub fn strict_cmp(self, other: &[u8]) -> Ordering
pub fn strict_cmp(self, other: &[u8]) -> Ordering
Compare with BCP-47 bytes.
The return value is equivalent to what would happen if you first converted
self to a BCP-47 string and then performed a byte comparison.
This function is case-sensitive and results in a total order, so it is appropriate for
binary search. The only argument producing Ordering::Equal
is self.as_str().as_bytes().
Sourcepub fn normalizing_eq(self, other: &str) -> bool
pub fn normalizing_eq(self, other: &str) -> bool
Compare with a potentially unnormalized BCP-47 string.
The return value is equivalent to what would happen if you first parsed the BCP-47 string and then performed a structural comparison.